@@ -1,5 +1,5 @@
 package Sys::Info::Driver::Linux::OS;
-$Sys::Info::Driver::Linux::OS::VERSION = '0.7907';
+$Sys::Info::Driver::Linux::OS::VERSION = '0.7908';
 use strict;
 use warnings;
 use parent qw( Sys::Info::Base );
@@ -27,9 +27,29 @@ sub edition {
 }
 
 sub tz {
-    my $self = shift;
-    return if ! -e proc->{timezone};
-    chomp( my $rv = $self->slurp( proc->{timezone} ) );
+    my $self        = shift;
+    my $old_tz_file = proc->{timezone_old};
+    my $tz_file     = proc->{timezone};
+    my $rv;
+
+    if ( -e $tz_file ) {
+        if ( ! -l $tz_file ) {
+            die "The timezone file $tz_file is not a symbolic link!";
+        }
+        else {
+            my $name = readlink $tz_file;
+            my $junk = quotemeta '/usr/share/zoneinfo/';
+            $name =~ s{ \A $junk }{}xmsg;
+            $rv = $name;
+        }
+    }
+    elsif ( -e $old_tz_file ) {
+        $rv = chomp( my $rv = $self->slurp( $old_tz_file ) );
+    }
+    else {
+        # warn?
+    }
+
     return $rv;
 }
 
@@ -267,7 +287,7 @@ Sys::Info::Driver::Linux::OS
 
 =head1 VERSION
 
-version 0.7907
+version 0.7908
 
 =head1 SYNOPSIS
 
